@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2.5
 # -*- coding: utf-8 -*-
 """ Handles contacts integration for fMMS
 
@@ -40,7 +40,9 @@ class ContactHandler:
 	def get_contacts_as_list(self):
 		retlist = []
 		for contact in self.contacts:
-			retlist.append(contact.get_name())
+			cn = contact.get_name()
+			if cn != None:
+				retlist.append(cn)
 		retlist.sort(key=str.lower)
 		return retlist
 	
