@@ -16,7 +16,7 @@ if __name__ == '__main__':
 	# Decode the specified file
 	fname = sys.argv[1]
 	
-	f = open(fname, 'rb')
+	"""f = open(fname, 'rb')
 	len = os.stat(fname)[6]
 	data2 = array.array('B')
 	data2.read(f, len)
@@ -31,7 +31,8 @@ if __name__ == '__main__':
 	#decoder = mms_pdu.MMSDecoder()
 	#wspdata = decoder.decodeData(data)
 	decoder = mms_pdu.MMSDecoder()
-	message = decoder.decodeResponseHeader(data)
+	message = decoder.decodeResponseHeader(data)"""
+	message = MMSMessage.fromFile(fname)
 	print message
 	
 	
