@@ -17,6 +17,7 @@ import fmms_sender_ui as fMMSSenderUI
 import contacts as ContactH
 import gobject
 import dbus
+import mimetypes
 
 class fMMS_GUI(hildon.Program):
 
@@ -37,6 +38,9 @@ class fMMS_GUI(hildon.Program):
 		hildon.Program.__init__(self)
 		program = hildon.Program.get_instance()
 		
+		self.osso_rpc = osso.Rpc(self.osso_c)
+      		self.osso_rpc.set_rpc_callback("se.frals.fmms","/se/frals/fmms","se.frals.fmms", self.cb_open_fmms, self.osso_c)
+		
 		self.window = hildon.StackableWindow()
 		self.window.set_title("fMMS")
 		program.add_window(self.window)
@@ -109,6 +113,23 @@ class fMMS_GUI(hildon.Program):
 			self.create_config_dialog()
 			self.config.set_firstlaunch(0)
 		
+	def cb_open_fmms(self, interface, method, args, user_data):
+		if method != 'open_mms' and method != 'open_gui':
+			return
+		if method == 'open_mms':
+			try:
+				checkfile = os.path.isfile(self._pushdir + args[0])
+				if checkfile == True:
+					filename = args[0]
+			except:
+				return
+			self.show_new_window(filename)
+		elif method == 'open_gui':
+			print "open_gui called"
+			self.liststore.clear()
+			self.add_buttons_liststore()
+			return
+		
 	def create_menu(self):
 		menu = hildon.AppMenu()
 		
@@ -394,7 +415,7 @@ class fMMS_GUI(hildon.Program):
 		dialog.destroy()
 		return
 	
-	""" action on delete contextmenu click """
+	""" action on redl contextmenu click """
 	def liststore_redl_clicked(self, widget):
 		(model, miter) = self.treeview.get_selection().get_selected()
 		# the 4th value is the filename (start counting at 0)
@@ -451,7 +472,7 @@ class fMMS_GUI(hildon.Program):
 		# this is ugly i know, but i really want it to work!
 		gobject.timeout_add(50, self.return_false)
 		try:
-			self.show_new_window(self, filename)
+			self.show_new_window(filename)
 		except:
 			pass
 		# this is ugly i know, but i really want it to work!
@@ -462,7 +483,7 @@ class fMMS_GUI(hildon.Program):
 		return False
 		
 	""" open a new window containing mms specified by fname """		
-	def show_new_window(self, widget, fname):
+	def show_new_window(self, fname):
 		win = hildon.StackableWindow()
 		win.set_title("Showing MMS: " + fname)
 	
@@ -565,8 +586,22 @@ class fMMS_GUI(hildon.Program):
 		filelist = os.listdir(path)
 		for fname in filelist:
 			(name, ext) = os.path.splitext(fname)
-			if ext == ".jpg" or ext == ".png":
+			fnpath = os.path.join(path, fname)
+			isText = False
+			isImage = False
+			try:
+				filetype = mimetypes.guess_type(fnpath)[0]
+				if filetype != None:
+					if filetype.startswith("image"):
+						isImage = True
+					if filetype.startswith("text"):
+						isText = True
+			except Exception, e:
+				filetype = None
+				print e, e.args
 			
+			# TODO: guess on content-type not fileextension, really
+			if isImage or ext == ".wbmp":
 				""" insert the image in an eventbox so we can get signals """
 				ebox = gtk.EventBox()
 				img = gtk.Image()
@@ -579,20 +614,25 @@ class fMMS_GUI(hildon.Program):
 				ebox.tap_and_hold_setup(menu)
 				#ebox.connect('tap-and-hold', self.mms_img_clicked)
 				container.add(ebox)
-			elif ext == ".txt" or ext.startswith(".txt"):
+			elif isText:
 				fp = open(path + "/" + fname, 'r')
 				contents = fp.read()
 				fp.close()
 				#print contents
 				textbuffer.insert(textbuffer.get_end_iter(), contents)
+			elif name != "message" and name != "headers" and not ext.startswith(".smil"):
+				attachButton = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL, fname)
+				attachButton.connect('clicked', self.mms_img_clicked, fnpath)
+				container.pack_end(attachButton, False, False, 0)
 				
 		textview.set_buffer(textbuffer)
 		container.add(textview)
 		
 	""" action on click on image """
 	def mms_img_clicked(self, widget, data):
+		print widget, data
 		path = "file://" + data
-		#print path
+		print path
 		rpc = osso.Rpc(self.osso_c)
 		rpc.rpc_run("com.nokia.image_viewer", "/com/nokia/image_viewer", "com.nokia.image_viewer", "mime_open", (str, path))
 		
