@@ -37,11 +37,6 @@ class fMMS_GUI(hildon.Program):
 			self.spawner = spawner
 		else:
 			self.spawner = self.window
-		
-		pan = hildon.PannableArea()
-		pan.set_property("mov-mode", hildon.MOVEMENT_MODE_BOTH)
-		
-		
 		allBox = gtk.VBox()
 		
 		""" Begin top section """
@@ -56,21 +51,17 @@ class fMMS_GUI(hildon.Program):
 		topHBox1.pack_start(bTo, False, True, 0)
 		topHBox1.pack_start(self.eNumber, True, True, 0)
 		
-		""" Ugly quick hack """
-		"""topHBox2 = gtk.HBox()
-		
-		bFrom = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL, "YOURNUMBER")
-		self.fNumber = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
-		
-		topHBox2.pack_start(bFrom, False, True, 0)
-		topHBox2.pack_start(self.fNumber, True, True, 0)"""
 		
 		""" Begin midsection """
-		midHBox = gtk.HBox()
+		pan = hildon.PannableArea()
+		pan.set_property("mov-mode", hildon.MOVEMENT_MODE_BOTH)		
+		
+		#midHBox = gtk.HBox()
 		self.tvMessage = hildon.TextView()
 		self.tvMessage.set_wrap_mode(gtk.WRAP_WORD)
 		
-		midHBox.pack_start(self.tvMessage, True, True, 0)
+		#midHBox.pack_start(self.tvMessage, True, True, 0)
+		pan.add_with_viewport(self.tvMessage)
 		
 		""" Begin botsection """
 		
@@ -93,12 +84,14 @@ class fMMS_GUI(hildon.Program):
 		""" Show it all! """
 		allBox.pack_start(topHBox1, False, False)
 		#allBox.pack_start(topHBox2, False, False)
-		allBox.pack_start(midHBox, True, True)
+		#allBox.pack_start(midHBox, True, True)
+		allBox.pack_start(pan, True, True)
 		allBox.pack_start(botHBox, False, False)
 		
-		self.pan = pan
-		self.pan.add_with_viewport(allBox)
-		self.window.add(self.pan)
+		#self.pan = pan
+		#self.pan.add_with_viewport(allBox)
+		#self.window.add(self.pan)
+		self.window.add(allBox)
 		self.window.show_all()
 		self.add_window(self.window)
 	
