@@ -370,6 +370,9 @@ class MMSDecoder(wsp_pdu.Decoder):
                 extension = 'txt'
             elif contentType == 'application/smil':
                 extension = 'smil'
+            else:
+            	extension = 'unknown'
+            
             
             ## TODO: FIX THIS ##
             dirname = self._path
@@ -380,14 +383,20 @@ class MMSDecoder(wsp_pdu.Decoder):
                 os.makedirs(dirname)
             filename = None
             print "MMSBODY HEADERS:", headers
-            ### THIS STUFF IS UGLY I KNOW, BUT IT *WORKS* 
-            """for k in headers:
-            	print k, headers[k]
-                h = headers[k][1]
-                if h.__class__ == dict:
-                    #filename = h['Name']
-                    pass
-            """
+            
+            ### loop through the headers, if we find a "name" header
+            ### using it seems like a good idea, right?
+	    try:
+			for k in headers:
+				print k, headers[k]
+				h = headers[k][1]
+				if h.__class__ == dict:
+				    filename = h['Name']
+ 	    except:
+			# this shouldnt really happen, but just in case...
+			pass
+
+            
             if filename != None:    
                 f = open(dirname + '/%s' % (filename), 'wb')
             else:
