@@ -47,6 +47,11 @@ class PushHandler:
 		dbus_loop = DBusGMainLoop()
 		args = (source, src_port, dst_port, wsp_header, wsp_payload)
 		
+		# TODO: dont hardcode
+		if not os.path.isdir('/home/user/.fmms/temp'):
+			print "creating dir /home/user/.fmms/temp"
+			os.makedirs("/home/user/.fmms/temp")
+		
 		f = open(self._incoming, 'w')
 		for arg in args:
 		    f.write(str(arg))
@@ -86,7 +91,7 @@ class PushHandler:
 		self.decodeMMS(path)
 		#_create_html(path, sndr)
 		# notify the user we downloaded it
-		self._notify_mms(dbus_loop, sndr, "New MMS", path);
+		self._notify_mms(dbus_loop, sndr, "New MMS", trans_id);
 		return 0
 
 
@@ -107,10 +112,10 @@ class PushHandler:
 		interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
 		choices = ['default', 'cancel']
 		if path == None:
-			interface.Notify('MMS', 0, '', message, sender, choices, {"category": "sms-message", "dialog-type": 4, "led-pattern": "PatternCommunicationEmail"}, -1)
+			interface.Notify('MMS', 0, '', message, sender, choices, {"category": "sms-message", "dialog-type": 4, "led-pattern": "PatternCommunicationEmail", "dbus-callback-default": "se.frals.fmms /se/frals/fmms se.frals.fmms open_gui"}, -1)
 		else:
 			# TODO: callback should open fMMS gui
-			interface.Notify("MMS", 0, '', message, sender, choices, {"category": "email-message", "dialog-type": 4, "led-pattern": "PatternCommunicationEmail", "dbus-callback-default": "com.nokia.osso_browser /com/nokia/osso_browser/request com.nokia.osso_browser load_url string:\"" + path + "\""}, -1)
+			interface.Notify("MMS", 0, '', message, sender, choices, {"category": "email-message", "dialog-type": 4, "led-pattern": "PatternCommunicationEmail", "dbus-callback-default": "se.frals.fmms /se/frals/fmms se.frals.fmms open_mms string:\"" + path + "\""}, -1)
 
 	""" saves the push message so we can reuse it """
 	def _save_push_message(self, transaction, decodeddata):
@@ -310,7 +315,8 @@ class MMSSender:
 			for b in out:
 				data.append(ord(b))
 			outparsed = decoder.decodeResponseHeader(data)
-		except:
+		except Exception, e:
+			print e, e.args
 			outparsed = out
 		
 		return res.status, res.reason, outparsed
\ No newline at end of file
